pub struct PauseNode { /* private fields */ }Expand description
PauseNode - Pauses execution for a specified duration
Similar to TimerNode but semantically represents a deliberate pause in behavior. Returns Running until the duration elapses, then returns Success.
Configuration
{
"type": "pause",
"config": {
"duration_secs": 2.0
}
}Implementations