pub struct NodeReference {
pub node_type: String,
pub config: Value,
pub name: Option<String>,
}Expand description
Reference to a behavior node that will be instantiated at runtime.
This is used by the execution engine to look up and instantiate behaviors.
Fields
node_type: StringNode type identifier
config: ValueConfiguration for the node
name: Option<String>Optional name for debugging